@@ -5,18 +5,17 @@
  */
 
 #include "incidenceresource.h"
-#include "resourcemanagement.h"
-#include "resourcemodel.h"
 #include "attendeecomboboxdelegate.h"
 #include "attendeelineeditdelegate.h"
 #include "incidencedatetime.h"
+#include "resourcemanagement.h"
+#include "resourcemodel.h"
 
 #include "ui_dialogdesktop.h"
 
 #include <KDescendantsProxyModel>
 #include <KEmailAddress>
 
-
 using namespace IncidenceEditorNG;
 
 class SwitchRoleProxy : public QSortFilterProxyModel
@@ -47,23 +46,20 @@ IncidenceResource::IncidenceResource(IncidenceAttendee *ieAttendee, IncidenceDat
     , resourceDialog(new ResourceManagement())
 {
     setObjectName(QStringLiteral("IncidenceResource"));
-    connect(resourceDialog, &ResourceManagement::accepted, this,
-            &IncidenceResource::dialogOkPressed);
+    connect(resourceDialog, &ResourceManagement::accepted, this, &IncidenceResource::dialogOkPressed);
 
-    connect(mDateTime, &IncidenceDateTime::startDateChanged, this,
-            &IncidenceResource::slotDateChanged);
-    connect(mDateTime, &IncidenceDateTime::endDateChanged, this,
-            &IncidenceResource::slotDateChanged);
+    connect(mDateTime, &IncidenceDateTime::startDateChanged, this, &IncidenceResource::slotDateChanged);
+    connect(mDateTime, &IncidenceDateTime::endDateChanged, this, &IncidenceResource::slotDateChanged);
 
     QStringList attrs;
-    attrs << QStringLiteral("cn") <<  QStringLiteral("mail");
+    attrs << QStringLiteral("cn") << QStringLiteral("mail");
 
     completer = new QCompleter(this);
-    auto *model = new ResourceModel(attrs, this);
+    auto model = new ResourceModel(attrs, this);
 
-    auto *proxyModel = new KDescendantsProxyModel(this);
+    auto proxyModel = new KDescendantsProxyModel(this);
     proxyModel->setSourceModel(model);
-    auto *proxyModel2 = new SwitchRoleProxy(this);
+    auto proxyModel2 = new SwitchRoleProxy(this);
     proxyModel2->setSourceModel(proxyModel);
 
     completer->setModel(proxyModel2);
@@ -71,36 +67,26 @@ IncidenceResource::IncidenceResource(IncidenceAttendee *ieAttendee, IncidenceDat
     completer->setWrapAround(false);
     mUi->mNewResource->setCompleter(completer);
 
-    auto *attendeeDelegate = new AttendeeLineEditDelegate(this);
+    auto attendeeDelegate = new AttendeeLineEditDelegate(this);
 
-    auto *filterProxyModel = new ResourceFilterProxyModel(this);
+    auto filterProxyModel = new ResourceFilterProxyModel(this);
     filterProxyModel->setDynamicSortFilter(true);
     filterProxyModel->setSourceModel(dataModel);
 
     mUi->mResourcesTable->setModel(filterProxyModel);
-    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Role,
-                                                   ieAttendee->roleDelegate());
+    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Role, ieAttendee->roleDelegate());
     mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::FullName, attendeeDelegate);
-    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Status,
-                                                   ieAttendee->stateDelegate());
-    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Response,
-                                                   ieAttendee->responseDelegate());
+    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Status, ieAttendee->stateDelegate());
+    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Response, ieAttendee->responseDelegate());
 
-    connect(mUi->mFindResourcesButton, &QPushButton::clicked, this,
-            &IncidenceResource::findResources);
-    connect(mUi->mBookResourceButton, &QPushButton::clicked, this,
-            &IncidenceResource::bookResource);
-    connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this,
-            &IncidenceResource::layoutChanged);
-    connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this,
-            &IncidenceResource::updateCount);
-    connect(filterProxyModel, &ResourceFilterProxyModel::rowsInserted, this,
-            &IncidenceResource::updateCount);
-    connect(filterProxyModel, &ResourceFilterProxyModel::rowsRemoved, this,
-            &IncidenceResource::updateCount);
+    connect(mUi->mFindResourcesButton, &QPushButton::clicked, this, &IncidenceResource::findResources);
+    connect(mUi->mBookResourceButton, &QPushButton::clicked, this, &IncidenceResource::bookResource);
+    connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this, &IncidenceResource::layoutChanged);
+    connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this, &IncidenceResource::updateCount);
+    connect(filterProxyModel, &ResourceFilterProxyModel::rowsInserted, this, &IncidenceResource::updateCount);
+    connect(filterProxyModel, &ResourceFilterProxyModel::rowsRemoved, this, &IncidenceResource::updateCount);
     // only update when FullName is changed
-    connect(filterProxyModel, &ResourceFilterProxyModel::dataChanged, this,
-            &IncidenceResource::updateCount);
+    connect(filterProxyModel, &ResourceFilterProxyModel::dataChanged, this, &IncidenceResource::updateCount);
 }
 
 IncidenceResource::~IncidenceResource()
@@ -110,7 +96,7 @@ IncidenceResource::~IncidenceResource()
 
 void IncidenceResource::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Q_UNUSED(incidence);
+    Q_UNUSED(incidence)
     slotDateChanged();
 }
 
@@ -121,13 +107,13 @@ void IncidenceResource::slotDateChanged()
 
 void IncidenceResource::save(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Q_UNUSED(incidence);
-    //all logic inside IncidenceAtendee (using same model)
+    Q_UNUSED(incidence)
+    // all logic inside IncidenceAtendee (using same model)
 }
 
 bool IncidenceResource::isDirty() const
 {
-    //all logic inside IncidenceAtendee (using same model)
+    // all logic inside IncidenceAtendee (using same model)
     return false;
 }
 
